@@ -293,7 +293,7 @@ bool SugarAccountHandler::offerTube(FV_View* pView, const UT_UTF8String& tubeDBu
 		pManager->registerEventListener(this);
 		// start hosting a session on the current document
 		UT_UTF8String sID;
-		pManager->startSession(pDoc, sID, NULL, "");
+		pManager->startSession(pDoc, sID, this, true, NULL, "");
 		return true;
 	}
 	else
@@ -409,6 +409,24 @@ void SugarAccountHandler::forceDisconnectBuddy(BuddyPtr pBuddy)
 	m_ignoredBuddies.insert(pBuddy->getDescriptor(false));
 }
 
+bool SugarAccountHandler::hasAccess(const std::vector<std::string>& /*vAcl*/, BuddyPtr pBuddy)
+{
+	UT_DEBUGMSG(("SugarAccountHandler::hasAccess() - pBuddy: %s\n", pBuddy->getDescriptor(false).utf8_str()));
+	UT_return_val_if_fail(pBuddy, false);
+
+	// The sugar presence service is responsible for access control. Just do a quick
+	// check here to see if we know the buddy on this account, and
+	// then be done with it.
+	SugarBuddyPtr pSugarBuddy = boost::dynamic_pointer_cast<SugarBuddy>(pBuddy);
+	UT_return_val_if_fail(pSugarBuddy, false);
+
+	SugarBuddyPtr pExistingBuddy = getBuddy(pSugarBuddy->getDBusAddress());
+	if (!pExistingBuddy)
+		false;
+
+	return true;
+}
+
 SugarBuddyPtr SugarAccountHandler::getBuddy(const UT_UTF8String& dbusAddress)
 {
 	for (std::vector<BuddyPtr>::iterator it = getBuddies().begin(); it != getBuddies().end(); it++)
@@ -529,7 +547,7 @@ DBusHandlerResult s_dbus_handle_message(DBusConnection *connection, DBusMessage
 				}
 
 				// FIXME: inefficient copying of data
-				std::string packet_str(' ', packet_size);
+				std::string packet_str(packet_size, ' ');
 				memcpy(&packet_str[0], packet_data, packet_size);
 				Packet* pPacket = pHandler->createPacket(packet_str, pBuddy);
 				UT_return_val_if_fail(pPacket, DBUS_HANDLER_RESULT_NOT_YET_HANDLED); // TODO: shouldn't we just disconnect here?
