@@ -39,7 +39,7 @@
 #include "ie_imp_GOComponent.h"
 #include <math.h>
 #include <goffice/component/go-component-factory.h>
-#include <goffice/utils/go-file.h>
+#include <goffice/goffice.h>
 #include <gsf/gsf-libxml.h>
 
 static void changed_cb (GOComponent*, gpointer);
@@ -389,7 +389,7 @@ void GR_GOComponentManager::makeSnapShot(UT_sint32 uid, UT_Rect & rec)
 		}
 		else
 		{
-			const char* mimetypeSVG = g_strdup("image/svg");
+			const std::string mimetypeSVG = "image/svg";
 			m_pDoc->createDataItem(sID.utf8_str(),false,reinterpret_cast< const UT_ByteBuf *>(pBuf),mimetypeSVG,NULL);
 			pItem->m_bHasSnapshot = true;
 		}
@@ -436,8 +436,7 @@ bool GR_GOComponentManager::createPNGSnapshot(AD_Document * pDoc, UT_Rect & rec,
   pImage->convertToBuffer(&pBuf);
   UT_UTF8String sID = "snapshot-png-";
   sID += szDataID;
-  const char* mimetypePNG = NULL;
-  mimetypePNG = g_strdup("image/png");
+  const std::string mimetypePNG = "image/png";
   pDoc->createDataItem(sID.utf8_str(),false,reinterpret_cast< const UT_ByteBuf *>(pBuf),mimetypePNG,NULL);
   delete pBuf;
   delete pImage;
@@ -494,17 +493,18 @@ void GR_GOComponentManager::loadEmbedData(G_GNUC_UNUSED UT_sint32 uid)
 	/* bool b = */ m_pDoc->getAttrProp(api, &pSpanAP);
 	const char * pszDataID = NULL;
 	bool bFoundDataID = pSpanAP->getAttribute("dataid", pszDataID);
-	char *mime_type;
+	std::string mime_type;
+
 	if (bFoundDataID && pszDataID)
 	{
 		const UT_ByteBuf * pByteBuf = NULL;
 		bFoundDataID = m_pDoc->getDataItemDataByName(pszDataID, 
 							const_cast<const UT_ByteBuf **>(&pByteBuf),
-							(const void**) (&mime_type), NULL);
+							&mime_type, NULL);
 		UT_return_if_fail(bFoundDataID);
 		UT_return_if_fail(pszDataID);
 		UT_DEBUGMSG(("GO Component string is... \n %s \n", (char*)pByteBuf));
-		pGOComponentView->loadBuffer(pByteBuf, mime_type);
+		pGOComponentView->loadBuffer(pByteBuf, mime_type.c_str());
 	}
 }
 
@@ -725,11 +725,11 @@ changed_cb (GOComponent *component, gpointer data)
 	}
 }
 
-void GOComponentView::loadBuffer(UT_ByteBuf const *sGOComponentData, char *_mime_type)
+void GOComponentView::loadBuffer(UT_ByteBuf const *sGOComponentData, const char *_mime_type)
 {
 	if (!component) {
 		mime_type = _mime_type;
-		component = go_component_new_by_mime_type (mime_type);
+		component = go_component_new_by_mime_type (_mime_type);
 	}
 	UT_return_if_fail (component);
 	g_signal_connect (G_OBJECT (component), "changed",
@@ -857,7 +857,7 @@ void GOComponentView::update ()
 				}
 			}
 		}
-		pView->cmdUpdateEmbed(m_pRun, &myByteBuf,mime_type,Props.c_str ());
+		pView->cmdUpdateEmbed(m_pRun, &myByteBuf,mime_type.c_str(),Props.c_str());
 		} else
 			pView->cmdDeleteEmbed(m_pRun);
 		if (clearfunc)
