@@ -39,12 +39,6 @@
 #include "AbiGOChart.h"
 #include "AbiGOComponent.h"
 
-#include <goffice/app/error-info.h>
-#include <goffice/app/go-cmd-context-impl.h>
-#include <goffice/app/go-plugin.h>
-#include <goffice/app/go-plugin-loader-module.h>
-#include <goffice/data/go-data-simple.h>
-#include <goffice/utils/go-file.h>
 #include <goffice/component/go-component-factory.h>
 #include <gsf/gsf-impl-utils.h>
 
@@ -63,9 +57,9 @@ abi_error_error (G_GNUC_UNUSED GOCmdContext *cc, GError *error)
 }
 
 static void
-abi_error_info (G_GNUC_UNUSED GOCmdContext *cc, ErrorInfo *error)
+abi_error_info (G_GNUC_UNUSED GOCmdContext *cc, GOErrorInfo *error)
 {
-	error_info_print (error);
+	go_error_info_print (error);
 }
 
 static char *
