@@ -1,7 +1,7 @@
 /*
-* * Copyright (C) 2004 Luca Padovani <lpadovan@cs.unibo.it>
+ * Copyright (C) 2004 Luca Padovani <lpadovan@cs.unibo.it>
  * Copyright (C) 2005 Martin Sevior <msevior@physics.unimelb.edu.au>
-  *
+ *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
  * as published by the Free Software Foundation; either version 2
@@ -179,7 +179,7 @@ static void AbiMathView_addToMenus()
 
 // Put it after Insert Picture in the Main menu
 
-    newEquationID= pFact->addNewMenuAfter("Main",NULL,AP_MENU_ID_INSERT_ENDNOTE,EV_MLF_BeginSubMenu);
+    newEquationID= pFact->addNewMenuAfter("Main",NULL,AP_MENU_ID_INSERT_GRAPHIC,EV_MLF_BeginSubMenu);
    UT_DEBUGMSG(("newEquationID %d \n",newEquationID));
 
 
@@ -429,7 +429,7 @@ static bool s_AskForMathMLPathname(XAP_Frame * pFrame,
 //   This is the function that we actually call to insert the MathML.
 //
 bool 
-AbiMathView_FileInsert(AV_View* /*v*/, EV_EditMethodCallData */*d*/)
+AbiMathView_FileInsert(AV_View* /*v*/, EV_EditMethodCallData* /*d*/)
 {
 	// Get the current view that the user is in.
 	XAP_Frame *pFrame = XAP_App::getApp()->getLastFocussedFrame();
@@ -463,12 +463,11 @@ AbiMathView_FileInsert(AV_View* /*v*/, EV_EditMethodCallData */*d*/)
 	}
 
 	/* Create the data item */
-	const char* mimetypeMATHML = NULL;
-	mimetypeMATHML = g_strdup("application/mathml+xml");
 	UT_uint32 uid = pDoc->getUID(UT_UniqueId::Image);
 	UT_UTF8String sUID;
 	UT_UTF8String_sprintf(sUID,"%d",uid);
-	pDoc->createDataItem(sUID.utf8_str(), false, pImpMathML->getByteBuf(), static_cast<void *>(const_cast<char *>(mimetypeMATHML)), NULL);
+	pDoc->createDataItem(sUID.utf8_str(), false, pImpMathML->getByteBuf(), 
+                         "application/mathml+xml", NULL);
 
 	/* Insert the MathML Object */
 	PT_DocPosition pos = pView->getPoint();
@@ -487,7 +486,7 @@ AbiMathView_FileInsert(AV_View* /*v*/, EV_EditMethodCallData */*d*/)
 //   a Latex expression.
 //
 bool 
-AbiMathView_LatexInsert(AV_View* v, EV_EditMethodCallData */*d*/)
+AbiMathView_LatexInsert(AV_View* v, EV_EditMethodCallData* /*d*/)
 {
 	FV_View * pView = static_cast<FV_View *>(v);
 	XAP_Frame * pFrame = static_cast<XAP_Frame *> ( pView->getParentData());
@@ -739,8 +738,6 @@ bool GR_MathManager::isDefault(void)
 bool GR_MathManager::createPNGSnapshot(AD_Document * pDoc, UT_Rect & rec,
 					   const char * szDataID)
 {
-	const char* mimetypePNG = NULL;
-
 	if (isDefault())
 	{
 		return false;
@@ -762,7 +759,7 @@ bool GR_MathManager::createPNGSnapshot(AD_Document * pDoc, UT_Rect & rec,
 	UT_UTF8String sID = "snapshot-png-";
 	sID += szDataID;
 
-	mimetypePNG = g_strdup("image/png");
+	const std::string mimetypePNG = "image/png";
 	UT_DEBUGMSG(("Making data-item of name %s \n",sID.utf8_str()));
 	pDoc->createDataItem(sID.utf8_str(),false,reinterpret_cast< const UT_ByteBuf *>(pBuf),mimetypePNG,NULL);
 
