@@ -157,7 +157,7 @@ void ODi_Frame_ListenerState::endElement (const gchar* pName,
             // Create the data item
             UT_uint32 id = m_pAbiDocument->getUID(UT_UniqueId::Math);
             UT_UTF8String sID = UT_UTF8String_sprintf("MathLatex%d", id);
-            m_pAbiDocument->createDataItem(sID.utf8_str(), false, m_pMathBB, NULL, NULL);
+            m_pAbiDocument->createDataItem(sID.utf8_str(), false, m_pMathBB, "", NULL);
 
             const gchar *atts[3] = { NULL, NULL, NULL };
             atts[0] = PT_IMAGE_DATAID;
@@ -558,6 +558,15 @@ void ODi_Frame_ListenerState::_drawTextBox (const gchar** ppAtts,
             }
         }
 
+
+        if(pGraphicStyle->getHorizPos(true) && !pGraphicStyle->getHorizPos(true)->empty()) 
+	{
+	       props += "; frame-horiz-align:";
+	       props += pGraphicStyle->getHorizPos(true)->utf8_str();
+            
+        }
+
+
     } else {  //just hard-code some defaults
         props += "bot-style:1; left-style:1; right-style:1; top-style:1";
     }
@@ -645,30 +654,32 @@ bool ODi_Frame_ListenerState::_getFrameProperties(UT_UTF8String& rProps,
         rProps += "; position-to:page-above-text";
         
         pVal = m_rElementStack.getStartTag(0)->getAttributeValue("svg:x");
-        UT_ASSERT(pVal);
-        rProps += "; frame-page-xpos:";
-        rProps += pVal;
+        if (pVal && *pVal) {
+            rProps += "; frame-page-xpos:";
+            rProps += pVal;
+        }
         
         pVal = m_rElementStack.getStartTag(0)->getAttributeValue("svg:y");
-        UT_ASSERT(pVal);
-        rProps += "; frame-page-ypos:";
-        rProps += pVal;
+        if (pVal && *pVal) {
+            rProps += "; frame-page-ypos:";
+            rProps += pVal;
+        }
         
     } else if (pVal && (!strcmp(pVal, "char") || !strcmp(pVal, "as-char"))) {
 		// AbiWord does not support anchoring frames/texboxes to chars; 
-		// let's just convert it to paragraph anchoring, so we don't loose the 
+		// let's just convert it to paragraph anchoring, so we don't lose the 
 		// entire frame
 		// FIXME: "char" means an inline thing in AbiWord terms, NOT a positioned thing
 		rProps += "; position-to:block-above-text";
 
 	    pVal = m_rElementStack.getStartTag(0)->getAttributeValue("svg:x");
-        if (pVal) {
+        if (pVal && *pVal) {
             rProps += "; xpos:";
             rProps += pVal;
         }
         
         pVal = m_rElementStack.getStartTag(0)->getAttributeValue("svg:y");
-        if (pVal) {
+        if (pVal && *pVal) {
             rProps += "; ypos:";
             rProps += pVal;
         }
@@ -706,15 +717,31 @@ bool ODi_Frame_ListenerState::_getFrameProperties(UT_UTF8String& rProps,
         }
     }
     UT_ASSERT_HARMLESS(pVal); // Is it really ok to not have a defined width?
-    if (pVal) {
+    if (pVal) 
+    {
         rProps += "; frame-width:";
         rProps += pVal;
     }
     
-    
-    
+    pVal = UT_getAttribute("style:rel-width", ppAtts);
+    if(pVal)
+    {
+        rProps += "; frame-rel-width:";
+        rProps += pVal;
+    }
+    else
+    {
+         pVal = m_rElementStack.getStartTag(0)->getAttributeValue("style:rel-width");
+	 if(pVal)
+	 {
+	      rProps += "; frame-rel-width:";
+	      rProps += pVal;
+	 }
+    }
+
     pVal = UT_getAttribute("fo:min-height", ppAtts);
-    if (pVal == NULL) {
+    if (pVal == NULL) 
+    {
         pVal = m_rElementStack.getStartTag(0)->getAttributeValue("svg:height");
         if (pVal == NULL) {
             pVal = m_rElementStack.getStartTag(0)->getAttributeValue("fo:min-height");
@@ -724,12 +751,17 @@ bool ODi_Frame_ListenerState::_getFrameProperties(UT_UTF8String& rProps,
                 UT_ASSERT_HARMLESS(UT_NOT_IMPLEMENTED);
             }
         }
-    } else {
-        if (UT_determineDimension(pVal, DIM_none) == DIM_PERCENT) {
+    } 
+    else 
+    {
+        if (UT_determineDimension(pVal, DIM_none) == DIM_PERCENT) 
+	{
             // TODO: Do the conversion from percentage to a real
             //       unit (ie: "cm" or "in").
             UT_ASSERT_HARMLESS(UT_NOT_IMPLEMENTED);
         }
+	rProps += "; frame-min-height:";
+	rProps += pVal;
     }
     if (pVal) {
         rProps += "; frame-height:";
