@@ -40,10 +40,12 @@
 #include "ut_misc.h"
 #include "ut_string.h"
 #include "ut_string_class.h"
+#include "ut_std_string.h"
 #include "ut_bytebuf.h"
 #include "ut_hash.h"
 #include "ut_vector.h"
 #include "ut_stack.h"
+#include "ut_math.h"
 
 #include "ut_debugmsg.h"
 
@@ -73,10 +75,10 @@ public:
   * Parse attributes array and map keys and values
   * to Abi's.
   */
-  void appendPageMaster(const gchar * name, const gchar ** atts) 
+  void appendPageMaster(const std::string & name, const gchar ** atts) 
   {
     // FIXME ATM only one page setup per document can be imported
-    if (m_name != "")
+    if (!m_name.empty())
     {
       UT_ASSERT(UT_SHOULD_NOT_HAPPEN);
     }
@@ -129,7 +131,7 @@ private:
     if (val)
     {
       width = rint(UT_convertToDimension(val, DIM_MM));
-      m_width = UT_String_sprintf("%f", width);
+      m_width = UT_std_string_sprintf("%f", width);
       m_pageAtts[propCtr++] = "width";
       m_pageAtts[propCtr++] = m_width.c_str();
     }
@@ -138,7 +140,7 @@ private:
     if (val)
     {
       height = rint(UT_convertToDimension(val, DIM_MM));
-      m_height = UT_String_sprintf("%f", height);
+      m_height = UT_std_string_sprintf("%f", height);
       m_pageAtts[propCtr++] = "height";
       m_pageAtts[propCtr++] = m_height.c_str();
     }
@@ -149,8 +151,9 @@ private:
     val = UT_getAttribute ("style:print-orientation", props);
     if (val)
     {
-      m_pageAtts[propCtr++] = "orientation";
-      m_pageAtts[propCtr++] = g_strdup (val);
+        m_orientation = val;
+        m_pageAtts[propCtr++] = "orientation";
+        m_pageAtts[propCtr++] = m_orientation.c_str();
     }
     
     m_pageAtts[propCtr++] = "page-scale";
@@ -196,10 +199,11 @@ private:
       m_sectionProps [m_sectionProps.size()-1] = 0; 
   }
   
-  UT_String m_name;
+  std::string m_name;
 
-  UT_String m_width;
-  UT_String m_height;
+  std::string m_width;
+  std::string m_height;
+  std::string m_orientation;
   
   UT_String m_marginLeft;
   UT_String m_marginTop;
@@ -693,16 +697,6 @@ IE_Imp_OpenWriter::IE_Imp_OpenWriter (PD_Document * pDocument)
 {
 }
 
-/*!
- * Destroy an OpenWriter importer object
- */
-IE_Imp_OpenWriter::~IE_Imp_OpenWriter ()
-{
-  if (m_oo)
-    g_object_unref (G_OBJECT(m_oo));
-
-  m_styleBucket.purgeData();
-}
 
 /*!
  * Import the given file
@@ -1003,13 +997,14 @@ class OpenWriter_StylesStream_Listener : public OpenWriter_Stream_Listener
 {
 public:
   OpenWriter_StylesStream_Listener ( IE_Imp_OpenWriter * importer, bool bOpenDocument )
-    : OpenWriter_Stream_Listener ( importer ), m_ooStyle (0), m_pageMaster(0), m_bOpenDocument(bOpenDocument)
+    : OpenWriter_Stream_Listener ( importer ), m_ooStyle (0), m_bOpenDocument(bOpenDocument)
   {
   }
   
   virtual ~OpenWriter_StylesStream_Listener ()
   {
     m_styleNameMap.purgeData();
+    DELETEP(m_ooStyle);
   }
 
   UT_UTF8String getStyleName(const UT_UTF8String & in) const
@@ -1079,7 +1074,7 @@ public:
     }
     else if (/* SXW || ODT */
 	     (!strcmp (name, "style:properties") || !strcmp (name, "style:page-layout-properties")) && 
-	     m_pageMaster) {
+	     !m_pageMaster.empty()) {
       // page setup, because we are in page-master subtree
       m_ooPageStyle.appendPageMaster(m_pageMaster, atts);
     }
@@ -1100,7 +1095,7 @@ public:
   virtual void endElement (const gchar * name)
   {
     if (!strcmp (name, "style:page-master")) {
-      m_pageMaster = NULL;
+      m_pageMaster.clear();
     }
     else if (!strcmp (name, "style:style")) {
       if (m_name.size ()) {
@@ -1173,7 +1168,7 @@ private:
   OO_Style *m_ooStyle;
   PD_Style *m_pParentStyle;
   OO_PageStyle m_ooPageStyle;
-  const gchar * m_pageMaster;
+  std::string m_pageMaster;
   const bool m_bOpenDocument;
 
   UT_GenericStringMap<UT_UTF8String *> m_styleNameMap;
@@ -1584,7 +1579,6 @@ private:
     if (error != UT_OK)
       return;
 
-    const char * mimetype 	= g_strdup ("image/png");
     FG_Graphic* pFG		= 0;
     const UT_ByteBuf * pictData       = 0;
     
@@ -1595,17 +1589,15 @@ private:
 	if ((error != UT_OK) || !pFG)
       {
 		  // pictData is already freed in ~FG_Graphic
-		  FREEP(mimetype);
 		  return;
       }
 
     // TODO: can we get back a vector graphic?
-    pictData = static_cast<FG_GraphicRaster *>(pFG)->getRaster_PNG();
+    pictData = pFG->getBuffer();
     
     if (!pictData)
       {
 		  // i don't think that this could ever happen, but...
-		  FREEP(mimetype);
 		  error = UT_ERROR;
 		  return;
       }
@@ -1626,12 +1618,11 @@ private:
     
     if (!getDocument()->appendObject (PTO_Image, propsArray))
       {
-		  FREEP(mimetype);
 		  return;
       }
 
     if (!getDocument()->createDataItem(propsName.c_str(), false,
-				       pictData, (void*)mimetype, NULL))
+                                       pictData, pFG->getMimeType(), NULL))
       {
 		  return;
       }
@@ -1805,3 +1796,16 @@ UT_Error IE_Imp_OpenWriter::_handleContentStream ()
   OpenWriter_ContentStream_Listener listener (this, m_pSSListener, m_bOpenDocument);
   return handleStream (m_oo, "content.xml", listener);
 }
+
+
+/*!
+ * Destroy an OpenWriter importer object
+ */
+IE_Imp_OpenWriter::~IE_Imp_OpenWriter ()
+{
+  if (m_oo)
+    g_object_unref (G_OBJECT(m_oo));
+
+  DELETEP(m_pSSListener);
+  m_styleBucket.purgeData();
+}
