@@ -192,7 +192,7 @@ enum GR_GraphicsId
 	GRID_WIN32           =  0x104,
 	GRID_UNIX            =  0x105,
 	GRID_UNIX_PS         =  0x106,
-	GRID_UNIX_NULL       =  0x107,
+	GRID_CAIRO_NULL      =  0x107,
 	
 	/*add new built-in ids here*/
 	
@@ -205,6 +205,7 @@ enum GR_GraphicsId
 	GRID_WIN32_UNISCRIBE =  0x202,
 	GRID_UNIX_PANGO_PRINT = 0x203,
 	GRID_UNIX_PANGO_PIXMAP = 0x204,
+        GRID_COCOA_PANGO     = 0x205,
 
 	GRID_LAST_EXTENSION = 0x0000ffff,
 
@@ -473,6 +474,7 @@ class ABI_EXPORT GR_Graphics
 
    	virtual GR_Image* createNewImage(const char* pszName,
 									 const UT_ByteBuf* pBB,
+									 const std::string& mimetype,
 									 UT_sint32 iWidth,
 									 UT_sint32 iHeight,
 									 GR_Image::GRType iType = GR_Image::GRT_Raster);
