@@ -166,11 +166,11 @@ dcl(DLG_FOSA_InsertObject,  "Insert Embeddable Object")
 dcl(DLG_FOSA_PrintToFileTitle,			"Print To File")
 dcl(DLG_FOSA_RecordToFileTitle,			"Record Editing to File")
 dcl(DLG_FOSA_ReplayFromFileTitle,		"Replay Editing from File")
-dcl(DLG_FOSA_FileOpenTypeLabel, 		"Open file as type:")
+dcl(DLG_FOSA_FileOpenTypeLabel, 		"Open file as &type:")
 dcl(DLG_FOSA_FileInsertMath, 		    "Insert MathML file:")
 dcl(DLG_FOSA_FileInsertObject, 		    "Insert Embeddable Object file:")
-dcl(DLG_FOSA_FileSaveTypeLabel, 		"Save file as type:")
-dcl(DLG_FOSA_FilePrintTypeLabel,		"Print file as type:")
+dcl(DLG_FOSA_FileSaveTypeLabel, 		"Save file as &type:")
+dcl(DLG_FOSA_FilePrintTypeLabel,		"Print file as &type:")
 dcl(DLG_FOSA_RecordToFileLabel,		    "File to record editing:")
 dcl(DLG_FOSA_ReplayFromFileLabel,		"File to replay editing:")
 dcl(DLG_FOSA_FileTypeAutoDetect,		"Automatically Detected")
