@@ -595,10 +595,7 @@ fl_AnnotationLayout::fl_AnnotationLayout(FL_DocLayout* pLayout,
 					 FL_SECTION_ANNOTATION,
 					 FL_CONTAINER_ANNOTATION,
 					 PTX_SectionAnnotation),
-	  m_iAnnotationPID(0),
-	  m_sAuthor("n/a"),
-	  m_sDate("n/a"),
-	  m_sTitle("n/a")
+	  m_iAnnotationPID(0)
 {
 	m_pLayout->addAnnotation(this);
 	_createAnnotationContainer();
@@ -732,7 +729,7 @@ void fl_AnnotationLayout::_insertAnnotationContainer(fp_Container * pNewAC)
 
 void fl_AnnotationLayout::format(void)
 {
-	xxx_UT_DEBUGMSG(("SEVIOR: Formatting first container is %x \n",getFirstContainer()));
+	UT_DEBUGMSG(("SEVIOR: Formatting Annotations first container is %x \n",getFirstContainer()));
 	if(getFirstContainer() == NULL)
 	{
 		getNewContainer();
@@ -789,32 +786,20 @@ void fl_AnnotationLayout::_lookupProperties(const PP_AttrProp* pSectionAP)
 	const char *pszDate;
 	if(!pSectionAP->getProperty("annotation-author", (const char *&)pszAuthor))
 	{
-	        pszAuthor = "n/a";
-	}
-	if(*pszAuthor == 0)
-        {
-	        pszAuthor = "n/a";
+	        pszAuthor = "";
 	}
 	m_sAuthor = pszAuthor;
 	if(!pSectionAP->getProperty("annotation-title", (const char *&)pszTitle))
 	{
-	        pszTitle = "n/a";
-	}
-	if(*pszTitle == 0)
-        {
-	        pszTitle = "n/a";
+	        pszTitle = "";
 	}
 	m_sTitle = pszTitle;
 	if(!pSectionAP->getProperty("annotation-date", (const char *&)pszDate))
 	{
-	        pszDate = "n/a";
-	}
-	if(*pszDate == 0)
-        {
-	        pszDate = "n/a";
+	        pszDate = "";
 	}
 	m_sDate = pszDate;
-	UT_DEBUGMSG(("Annotation _lookupProps Author|%s| Title |%s| \n",m_sAuthor.utf8_str(),m_sTitle.utf8_str()));
+	UT_DEBUGMSG(("Annotation _lookupProps Author|%s| Title |%s| \n", m_sAuthor.utf8_str(),m_sTitle.utf8_str()));
 }
 
 void fl_AnnotationLayout::_localCollapse(void)
