@@ -50,7 +50,8 @@ fp_ContainerObject::fp_ContainerObject(FP_ContainerType iType, fl_SectionLayout*
 			m_pSectionLayout(pSectionLayout),
 			m_iDirection(UT_BIDI_UNSET),
 		m_iBreakTick(0),
-		m_iRef(0)
+		m_iRef(0),
+		m_bCanDelete(true)
 {
 	UT_ASSERT(pSectionLayout);
 }
@@ -101,6 +102,7 @@ const char * fp_ContainerObject::getContainerString(void)
 fp_ContainerObject::~fp_ContainerObject()
 {
 	m_iConType = static_cast<FP_ContainerType>(-1);
+	//	UT_ASSERT(m_bCanDelete);
 }
 
 /*!
@@ -119,6 +121,27 @@ bool fp_ContainerObject::isColumnType(void) const
   return b;
 }
 
+/*!
+ * Return the DocSectionLayout that owns this
+ */
+fl_DocSectionLayout * fp_ContainerObject::getDocSectionLayout(void)
+{
+    fl_ContainerLayout * pCL = static_cast<fl_ContainerLayout *>(getSectionLayout());
+    while(pCL && (pCL->getContainerType() != FL_CONTAINER_DOCSECTION) && (pCL->getContainerType() != FL_CONTAINER_HDRFTR))
+    {
+        xxx_UT_DEBUGMSG(("getDocSectionLayout: Container type %s \n",getContainerString()));
+        pCL = pCL->myContainingLayout();
+    }
+    if(pCL && (pCL->getContainerType() == FL_CONTAINER_HDRFTR))
+    {
+        return static_cast<fl_HdrFtrSectionLayout *>(pCL)->getDocSectionLayout();
+    }
+    else if(pCL)
+    {
+        return static_cast<fl_DocSectionLayout *>(pCL);
+    }
+    return NULL;
+}
 /*!
  * Return a pointer to the Graphics class for this object
  */
@@ -831,11 +854,26 @@ void fg_FillType::setHeight(GR_Graphics * pG, UT_sint32 iHeight)
  */
 void fg_FillType::Fill(GR_Graphics * pG, UT_sint32 & srcX, UT_sint32 & srcY, UT_sint32 x, UT_sint32 y, UT_sint32 width, UT_sint32 height)
 {
+	if(y < -9999999)
+	{
+	     // Whoops! object is offscreen!
+	     // Bailout
+	     return;
+	}
+
+  //
+  // Images appear to be 1 pixel narrower than rectangular
+  // fills
+  //
+        UT_sint32 imageOffset = pG->tlu(1);
+
+
 //
 // Have to adjust for spacing between cells
 //
 	GR_Painter painter(pG);
-
+	UT_RGBColor white(255,255,255);
+	bool bIsFrame = false;
 	if(m_pContainer && (m_pContainer->getContainerType() == FP_CONTAINER_CELL))
 	{
 		const fp_CellContainer * pCell = static_cast<const fp_CellContainer *>(m_pContainer);
@@ -856,6 +894,16 @@ void fg_FillType::Fill(GR_Graphics * pG, UT_sint32 & srcX, UT_sint32 & srcY, UT_
 		{
 			srcX += xoff;
 			srcY += yoff;
+			bIsFrame = true;
+		}
+		if(getParent() && ((m_FillType == FG_FILL_IMAGE) || (m_FillType == FG_FILL_TRANSPARENT) ))
+		{
+			m_color = getParent()->m_color;
+			m_bColorSet = getParent()->m_bColorSet;
+			m_TransColor = getParent()->m_TransColor;
+			m_bTransColorSet = getParent()->m_bTransColorSet;
+			if(m_pDocImage == NULL)
+			    m_pDocImage = getParent()->m_pDocImage;
 		}
 	}
 	if(m_pContainer && (m_pContainer->getContainerType() == FP_CONTAINER_RUN))
@@ -910,7 +958,6 @@ void fg_FillType::Fill(GR_Graphics * pG, UT_sint32 & srcX, UT_sint32 & srcY, UT_
 //
 // Overwrite With white first for alpha blended images
 //
-			 UT_RGBColor white(255,255,255);
 			 if(!pG->queryProperties(GR_Graphics::DGP_PAPER))
 			 {
 			         painter.fillRect(white,dest);
@@ -921,7 +968,14 @@ void fg_FillType::Fill(GR_Graphics * pG, UT_sint32 & srcX, UT_sint32 & srcY, UT_
 			 }
 			 else if(*m_pDocImage)
 			 {
+			   if(!bIsFrame)
+			   {
 				 painter.fillRect(*m_pDocImage,src,dest);
+			   }
+			   else
+			   {
+			         painter.drawImage(*m_pDocImage, dest.left,dest.top);
+			   }
 			 }
 			 return;
 		 }
@@ -931,9 +985,9 @@ void fg_FillType::Fill(GR_Graphics * pG, UT_sint32 & srcX, UT_sint32 & srcY, UT_
 			 return;
 		 }
 		 return;
-	 }
-	 if(m_FillType == FG_FILL_TRANSPARENT)
-	 {
+	}
+	if(m_FillType == FG_FILL_TRANSPARENT)
+	{
 		 xxx_UT_DEBUGMSG(("Fill type transparent ! \n"));
 		 if(getParent() && m_pContainer)
 		 {
@@ -944,18 +998,17 @@ void fg_FillType::Fill(GR_Graphics * pG, UT_sint32 & srcX, UT_sint32 & srcY, UT_
 			 return;
 		 }
 		 xxx_UT_DEBUGMSG(("Fill type transparent but no parent ! \n"));
-		 UT_RGBColor white(255,255,255);
 		 painter.fillRect(white,x,y,width,height);
 		 return;
-	 }
-	 if(m_FillType == FG_FILL_COLOR && m_bColorSet)
-	 {
+	}
+	if(m_FillType == FG_FILL_COLOR && m_bColorSet)
+	{
 		 xxx_UT_DEBUGMSG(("Fill type Color ! \n"));
 		 painter.fillRect(m_color,x,y,width,height);
 		 return;
-	 }
-	 if(m_FillType == FG_FILL_IMAGE)
-	 {
+	}
+	if(m_FillType == FG_FILL_IMAGE)
+	{
 		 xxx_UT_DEBUGMSG(("Fill type Image ! srcX %d srcY %d x  %d y %d width %d height %d \n",srcX,srcY,x,y,width,height));
 		 if((m_pDocImage == NULL) && (m_pDocLayout->getGraphicTick() != m_iGraphicTick))
 		 {
@@ -966,7 +1019,6 @@ void fg_FillType::Fill(GR_Graphics * pG, UT_sint32 & srcX, UT_sint32 & srcY, UT_
 		 {
 			 UT_sint32 iX = -srcX;
 			 srcX = 0;
-			 UT_RGBColor white(255,255,255);
 			 painter.fillRect(white,x,y,iX,height);
 			 width -= iX;
 		 }
@@ -975,18 +1027,23 @@ void fg_FillType::Fill(GR_Graphics * pG, UT_sint32 & srcX, UT_sint32 & srcY, UT_
 		 {
 			 UT_sint32 iY = -srcY;
 			 srcY = 0;
-			 UT_RGBColor white(255,255,255);
 			 painter.fillRect(white,x,y,width,iY);
 			 height -= iY;
 		 }
+		 if(m_pContainer) 
+         {
+		   xxx_UT_DEBUGMSG((" ContainerType %s \n ",m_pContainer->getContainerString()));
+         }
+		 xxx_UT_DEBUGMSG(("m_pDocImage %p  Trans col %d m_bColorSet %d \n ",m_pDocImage, m_bTransColorSet, m_bColorSet));
+
 		src.left = srcX;
 		src.top = srcY;
-		src.width = width;
-		src.height = height;
+		src.width = width+imageOffset;
+		src.height = height+imageOffset;
 		dest.left = x;
 		dest.top = y;
-		dest.width = width;
-		dest.height = height;
+		dest.width = width+imageOffset;
+		dest.height = height+imageOffset;
 //
 // Only fill the bits exposed by the clip rect
 //
@@ -1045,24 +1102,52 @@ void fg_FillType::Fill(GR_Graphics * pG, UT_sint32 & srcX, UT_sint32 & srcY, UT_
 
 		if(m_pDocImage == NULL)
 		{
+		        if(m_bTransColorSet)
+			{
+			    painter.fillRect(m_TransColor,x,y,width,height);
+			}
+			else if(m_bColorSet)
+			{
+			    painter.fillRect(m_color,x,y,width,height);
+			}
+			else
+			{
+			    painter.fillRect(white,x,y,width,height);
+			}
 			painter.fillRect(m_pImage,src,dest);
 		}
 		else if(*m_pDocImage)
 		{
+		        if(m_bTransColorSet)
+			{
+			    painter.fillRect(m_TransColor,x,y,width,height);
+			}
+			else if(m_bColorSet)
+			{
+			    painter.fillRect(m_color,x,y,width,height);
+			}
+			else if(getParent() && getParent()->m_pDocImage && *getParent()->m_pDocImage)
+			{
+			    painter.fillRect(white,x,y,width,height);
+			    painter.fillRect(*getParent()->m_pDocImage,src,dest);
+			}
+			else
+			{
+			    painter.fillRect(white,x,y,width,height);
+			}
 			painter.fillRect(*m_pDocImage,src,dest);
 		}
 		else
 		{
-			UT_RGBColor white(255,255,255);
 			painter.fillRect(white,x,y,width,height);
 		}
 	}		
-	 if(m_FillType == FG_FILL_COLOR && m_bTransColorSet)
-	 {
+	if(m_FillType == FG_FILL_COLOR && m_bTransColorSet)
+        {
 		 xxx_UT_DEBUGMSG(("Fill type Trans Color ! \n"));
 		 painter.fillRect(m_TransColor,x,y,width,height);
 		 return;
-	 }
+	}
 	return;
 }
 
