@@ -99,7 +99,7 @@ fp_TextRun::fp_TextRun(fl_BlockLayout* pBL,
 	if(!s_iClassInstanceCount)
 	{
 		s_bBidiOS = (XAP_App::getApp()->theOSHasBidiSupport() == XAP_App::BIDI_SUPPORT_FULL);
-		UT_DEBUGMSG(("fp_TextRun size is %d\n",sizeof(fp_TextRun) ));
+		UT_DEBUGMSG(("fp_TextRun size is %zd\n",sizeof(fp_TextRun) ));
 	}
 
 	s_iClassInstanceCount++;
@@ -739,7 +739,6 @@ void fp_TextRun::mapXYToPosition(UT_sint32 x, UT_sint32 y,
 			// don't set bBOL to false here
 			bEOL = false;
 		}
-
 		return;
 	}
 
@@ -768,7 +767,6 @@ void fp_TextRun::mapXYToPosition(UT_sint32 x, UT_sint32 y,
 			// the correct place to do it.	2001.02.25 jskov
 			bEOL = true;
 		}
-
 		return;
 	}
 
@@ -803,6 +801,7 @@ void fp_TextRun::mapXYToPosition(UT_sint32 x, UT_sint32 y,
 
 			bBOL = false;
 			bEOL = false;
+			pos += adjustCaretPosition(pos,true);
 			return;
 		}
 
@@ -836,13 +835,14 @@ void fp_TextRun::mapXYToPosition(UT_sint32 x, UT_sint32 y,
 					iLog = getLength() - i;
 				
 				pos = getBlock()->getPosition() + getBlockOffset() + iLog;
+				pos += adjustCaretPosition(pos,true);
 				return;
 			}
 		}
 	}
 	else
 	{
-#ifdef TOOLKIT_GTK
+#ifdef WITH_CAIRO
 		// This is really for the benefit of the Pango graphics, which requires the raw
 		// text for almost anything; we do not need this on win32, and since this this
 		// called all the time, do not want it in here unless necessary
@@ -858,10 +858,11 @@ void fp_TextRun::mapXYToPosition(UT_sint32 x, UT_sint32 y,
 		pos = getGraphics()->XYToPosition(*m_pRenderInfo, x, y);
 		pos += getBlock()->getPosition() + getBlockOffset();
 
-#ifdef TOOLKIT_GTK
+#ifdef WITH_CAIRO
 		// reset this, so we have no stale pointers there
 		m_pRenderInfo->m_pText = NULL;
 #endif
+		pos = adjustCaretPosition(pos,true);
 		return;
 	}
 	
@@ -877,18 +878,19 @@ void fp_TextRun::findPointCoords(UT_uint32 iOffset, UT_sint32& x, UT_sint32& y,
 	UT_sint32 yoff2;
 	UT_sint32 xdiff = 0;
 	xxx_UT_DEBUGMSG(("findPointCoords: Text Run offset %d \n",iOffset));
-
 	if(!m_pRenderInfo || _getRefreshDrawBuffer() == GRSR_Unknown)
 	{
 		// this can happen immediately after run is inserted at the
 		// end of a paragraph.
 		_refreshDrawBuffer();
 	}
-
 	UT_return_if_fail(m_pRenderInfo);
 	
 	UT_return_if_fail(getLine());
 
+	//	UT_uint32 docPos = getBlockOffset() + getBlock()->getPosition() +iOffset;
+	//docPos = adjustCaretPosition(docPos,true);
+	//iOffset = docPos - getBlockOffset() + getBlock()->getPosition();
 	getLine()->getOffsets(this, xoff, yoff);
 
 	if (m_fPosition == TEXT_POSITION_SUPERSCRIPT)
@@ -974,7 +976,7 @@ void fp_TextRun::findPointCoords(UT_uint32 iOffset, UT_sint32& x, UT_sint32& y,
 		m_pRenderInfo->m_iOffset = iOffset - getBlockOffset() - 1;
 		m_pRenderInfo->m_iLength = getLength();
 
-#ifdef TOOLKIT_GTK
+#ifdef WITH_CAIRO
 		// This is really for the benefit of the Pango graphics, which requires the raw
 		// text for almost anything; we do not need this on win32, and since this this
 		// called all the time, do not want it in
@@ -988,7 +990,7 @@ void fp_TextRun::findPointCoords(UT_uint32 iOffset, UT_sint32& x, UT_sint32& y,
 		x += xoff;
 		x2 += xoff;
 		
-#ifdef TOOLKIT_GTK
+#ifdef WITH_CAIRO
 		// reset this, so we have no stale pointers there
 		m_pRenderInfo->m_pText = NULL;
 #endif
@@ -1068,6 +1070,8 @@ bool fp_TextRun::canMergeWithNext(void)
 		|| (pNext->getVisibility() != getVisibility())
 		// Different authors
 		|| (pNext->getAuthorNum() != getAuthorNum())
+		// The merge must make just one item
+		|| (!isOneItem(pNext))
 #if 0
 		// I do not think this should happen at all
 		|| ((pNext->m_bRenderInfo->isJustified() && m_bRenderInfo->isJustified())
@@ -1133,61 +1137,10 @@ void fp_TextRun::mergeWithNext(void)
 
 	// can only adjust width after the justification has been handled
  	_setWidth(getWidth() + pNext->getWidth());
-
-
-	// the shaping requirenments of the combined run
-	UT_ASSERT( m_pRenderInfo );
-	if(m_pRenderInfo && pNext && pNext->m_pRenderInfo)
-	{
-		m_pRenderInfo->m_eShapingResult =
-			(GRShapingResult)((UT_uint32)m_pRenderInfo->m_eShapingResult
-							  | (UT_uint32)(pNext->	m_pRenderInfo->m_eShapingResult));
-
-		// because there might be a ligature across the run boundary, we
-		// have to refresh
-		// get the current refresh state
-		GRShapingResult eR = _getRefreshDrawBuffer();
-		eR = (GRShapingResult)((UT_uint32)eR | (UT_uint32)pNext->_getRefreshDrawBuffer());
-
-		if(((UT_uint32)	m_pRenderInfo->m_eShapingResult & (UT_uint32)GRSR_Ligatures) != 0)
-		{
-			// our run contains ligating characters, see if one is at the end
-			eR = (GRShapingResult)((UT_uint32)eR | (UT_uint32) GRSR_Ligatures);		
-		}
-
-		_setRefreshDrawBuffer(eR);
-	}
-	
-
-
-	// we need to take into consideration whether this run has been reversed
-	// in which case the order of the concating needs to be reversed too
-	UT_BidiCharType iVisDirection = getVisDirection();
-
-	bool bReverse = (!s_bBidiOS && iVisDirection == UT_BIDI_RTL)
-		  || (s_bBidiOS && m_iDirOverride == UT_BIDI_RTL && _getDirection() == UT_BIDI_LTR)
-		  || (s_bBidiOS && m_iDirOverride == UT_BIDI_LTR && _getDirection() == UT_BIDI_RTL);
-
-	UT_uint32 iNextLen = pNext->getLength();
-	UT_uint32 iMyLen   = getLength();
-
-	UT_ASSERT( m_pRenderInfo &&  pNext->m_pRenderInfo);
-	if(m_pRenderInfo &&  pNext->m_pRenderInfo)
-	{
-		m_pRenderInfo->m_iLength = iMyLen;
-		pNext->m_pRenderInfo->m_iLength = iNextLen;
-		
-		if(!m_pRenderInfo->append(*(pNext->m_pRenderInfo), bReverse))
-		{
-			// either the graphics class does not have append capabilities, or the append failed
-			// -- we mark the draw buffer for recalculation
-			_setRefreshDrawBuffer(GRSR_Unknown);
-		}
-		
-	}
-	
-
-	_setLength(iMyLen + iNextLen);
+	_setLength(getLength() + pNext->getLength());
+	DELETEP(m_pRenderInfo);
+	m_pRenderInfo = NULL;
+	itemize();
 	_setDirty(isDirty() || pNext->isDirty());
 
 	setNextRun(pNext->getNextRun(), false);
@@ -1198,28 +1151,12 @@ void fp_TextRun::mergeWithNext(void)
 	}
 
 	pNext->getLine()->removeRun(pNext, false);
-
-	// if appending a strong run onto a weak one, make sure the overall direction
-	// is that of the strong run, and tell the line about this, since the call
-	// to removeRun above decreased the line's direction counter
-	if(!UT_BIDI_IS_STRONG(_getDirection()) && UT_BIDI_IS_STRONG(pNext->_getDirection()))
-	{
-		_setDirection(pNext->_getDirection());
-		getLine()->addDirectionUsed(_getDirection());
-	}
-	else if(UT_BIDI_IS_WEAK(_getDirection()) && UT_BIDI_IS_WEAK(pNext->_getDirection()))
-	{
-		// numbers will take precedence
-		if(UT_BIDI_IS_NUMBER(pNext->_getDirection()))
-		{
-			_setDirection(pNext->_getDirection());
-			// no need to inform the line, since the visual direction
-			// is not going to change
-		}
-	}
+	lookupProperties();
 	setMustClearScreen();
+	markDrawBufferDirty();
 
 	delete pNext;
+
 }
 
 bool fp_TextRun::split(UT_uint32 iSplitOffset)
@@ -1235,10 +1172,6 @@ bool fp_TextRun::split(UT_uint32 iSplitOffset)
 
 	UT_ASSERT(pNew);
 
-	// when spliting the run, we do not want to recalculated the draw
-	// buffer if the current one is up to date
-	pNew->_setRefreshDrawBuffer(_getRefreshDrawBuffer());
-
 	pNew->_setFont(this->_getFont());
 
 	pNew->_setDecorations(this->_getDecorations());
@@ -1289,74 +1222,23 @@ bool fp_TextRun::split(UT_uint32 iSplitOffset)
 	}
 	setNextRun(pNew, false);
 
-	// split the rendering info, this will save us refreshing it
-	// which is very expensive (see notes on the mergeWithNext())
-	bool bReverse = ((!s_bBidiOS && iVisDirection == UT_BIDI_RTL)
-			 || (s_bBidiOS && m_iDirOverride == UT_BIDI_RTL && _getDirection() == UT_BIDI_LTR)
-			 || (s_bBidiOS && m_iDirOverride == UT_BIDI_LTR && _getDirection() == UT_BIDI_RTL));
+	// reitemize this run and blow away all the old render info. It has to be
+	// recalculated.
 
-	// runs can be split even before any shaping has been done on the, in which case we do not have
-	// the redering info yet; in such cases we only have m_pItem
-	bool bSplitSucceeded = true;
-	
-	if(m_pRenderInfo)
-	{
-		m_pRenderInfo->m_pGraphics = getGraphics();
-		m_pRenderInfo->m_pFont = getFont();
-		m_pRenderInfo->m_iLength = getLength();
-		m_pRenderInfo->m_iOffset = iSplitOffset - getBlockOffset();
-		if(!m_pRenderInfo->split(pNew->m_pRenderInfo, bReverse))
-		{
-			// the graphics class is either incapable of spliting, or the operation failed
-			// we need to mark both runs for shaping
-			_setRefreshDrawBuffer(GRSR_Unknown);
-			pNew->_setRefreshDrawBuffer(GRSR_Unknown);
-			bSplitSucceeded = false;
-		}
-		
-
-		// the split function created a copy of GR_Item in the render
-		// info; bring the member into sync with it (m_pItem is where the GR_Item lives and where it
-		// is destroyed)
-		if(pNew->m_pRenderInfo)
-		{
-			pNew->m_pItem = pNew->m_pRenderInfo->m_pItem;
-		}
-	}
-	else
-	{
-		// if this assert falls, we are in real trouble ...
-		UT_ASSERT_HARMLESS( m_pItem );
-		if(m_pItem)
-		{
-			pNew->m_pItem = m_pItem->makeCopy();
-		}
-	}
-	
-	
-
-	
 	setLength(iSplitOffset - getBlockOffset(), false);
+	DELETEP(m_pRenderInfo);
+	itemize();
+	lookupProperties();
+	// Reitemize the new run
+	pNew->itemize();
 
 	if(getLine())
 		getLine()->insertRunAfter(pNew, this);
 
-	// we will use the _addupCharWidths() function here instead of recalcWidth(), since when
-	// a run is split the info in the block's char-width array is not affected, so we do not
 	//have to recalculate these
 
-	if(bSplitSucceeded)
-	{
-		_addupCharWidths();
-		pNew->_addupCharWidths();
-	}
-	else
-	{
-		recalcWidth();
-		pNew->recalcWidth();
-	}
-	
-
+	recalcWidth();
+	pNew->recalcWidth();
 
 	//bool bDomDirection = getBlock()->getDominantDirection();
 
@@ -1371,7 +1253,6 @@ bool fp_TextRun::split(UT_uint32 iSplitOffset)
 	}
 
 	pNew->_setY(getY());
-
 	return true;
 }
 
@@ -2194,6 +2075,7 @@ bool fp_TextRun::_refreshDrawBuffer()
 							  getBlockOffset() + fl_BLOCK_STRUX_OFFSET);
 
 		bool lastWasSpace = false;
+
 		if (getTextTransform() == GR_ShapingInfo::CAPITALIZE) {
 			fp_Run* prevRun = getPreviousInterestingRunForCapitalization(this->getPrevRun());
 			if (prevRun == NULL) {
@@ -2782,7 +2664,7 @@ void fp_TextRun::justify(UT_sint32 iAmount, UT_uint32 iSpacesInRun)
 	
 		_setWidth(getWidth() + iAmount);
 
-#ifdef TOOLKIT_GTK
+#ifdef WITH_CAIRO
 		// Because Pango does not yet support justification, we need to iterate over the raw
 		// text counting spaces; this is not required by the default graphics class, nor
 		// Uniscribe and for performance reasons it is therefore only conditionally compiled
@@ -2802,7 +2684,7 @@ void fp_TextRun::justify(UT_sint32 iAmount, UT_uint32 iSpacesInRun)
 		m_pRenderInfo->m_iJustificationAmount = iAmount;
 		getGraphics()->justify(*m_pRenderInfo);
 
-#ifdef TOOLKIT_GTK
+#ifdef WITH_CAIRO
 		// do not leave stale pointer behind
 		m_pRenderInfo->m_pText = NULL;
 #endif
@@ -2823,7 +2705,7 @@ UT_sint32 fp_TextRun::countJustificationPoints(bool bLast) const
 
 	UT_return_val_if_fail(m_pRenderInfo->m_iLength > 0, 0);
 
-#ifdef TOOLKIT_GTK
+#ifdef WITH_CAIRO
 	// Because Pango does not yet support justification, we need to iterate over the raw
 	// text counting spaces; this is not required by the default graphics class, nor
 	// Uniscribe and for performance reasons it is therefore only conditionally compiled
@@ -2841,7 +2723,7 @@ UT_sint32 fp_TextRun::countJustificationPoints(bool bLast) const
 	m_pRenderInfo->m_bLastOnLine = bLast;
 	UT_sint32 iCount = getGraphics()->countJustificationPoints(*m_pRenderInfo);
 
-#ifdef TOOLKIT_GTK
+#ifdef WITH_CAIRO
 	m_pRenderInfo->m_pText = NULL;
 #endif
 
@@ -2898,6 +2780,72 @@ UT_sint32 fp_TextRun::getStr(UT_UCSChar * pStr, UT_uint32 &iMax)
 	return -1;
 }
 
+/*!
+ * Returns true if this run plus the next can be combined to make 
+ * one contiguous item
+ */
+bool fp_TextRun::isOneItem(fp_Run * pNext)
+{
+	GR_Itemization I;
+	bool b = getBlock()->itemizeSpan(getBlockOffset(), getLength()+pNext->getLength(),I);
+	UT_return_val_if_fail(b,false);
+	UT_DEBUGMSG(("Found %d items \n",I.getItemCount()-1));
+	if(I.getItemCount() <= 2)
+	{
+		//
+		// Now look to see if there is roman text mixed with
+		// Unicode. Can easily happen with numbers or smart quotes
+		//
+		PD_StruxIterator text(getBlock()->getStruxDocHandle(),
+						  getBlockOffset() + fl_BLOCK_STRUX_OFFSET);
+
+		text.setUpperLimit(text.getPosition() + getLength()+ pNext->getLength() - 1);
+		UT_ASSERT_HARMLESS( text.getStatus() == UTIter_OK );
+		bool bFoundRoman = false;
+		bool bFoundUnicode = false;
+		while(text.getStatus() == UTIter_OK)
+	    {
+			UT_UCS4Char c = text.getChar();
+			if(c != ' ' && c <256)
+			{
+				bFoundRoman = true;
+			}
+			else if(c!= ' ' && !UT_isSmartQuotedCharacter(c))
+			{
+				bFoundUnicode = true;
+			}
+			++text;
+		}
+		if(bFoundRoman && bFoundUnicode)
+		{
+			return false;
+		}
+		return true;
+	}
+	return false;
+}
+void fp_TextRun::itemize(void)
+{
+	GR_Itemization I;
+	bool b = getBlock()->itemizeSpan(getBlockOffset(), getLength(),I);
+	UT_return_if_fail(b);
+	//
+	// Should only be one item per run
+	//
+	GR_Item * pItem = I.getNthItem(0)->makeCopy();
+	UT_return_if_fail(pItem);
+	setItem(pItem->makeCopy());
+}
+
+void fp_TextRun::setItem(GR_Item * i)
+{
+	DELETEP(m_pItem);
+	m_pItem =i;
+	if(m_pRenderInfo)
+	{
+		m_pRenderInfo->m_pItem = m_pItem;
+	}
+}
 
 void fp_TextRun::setDirection(UT_BidiCharType dir, UT_BidiCharType dirOverride)
 {
@@ -3392,9 +3340,10 @@ void fp_TextRun::updateOnDelete(UT_uint32 offset, UT_uint32 iLenToDelete)
 
 UT_uint32 fp_TextRun::adjustCaretPosition(UT_uint32 iDocumentPosition, bool bForward)
 {
+
 	UT_uint32 iRunOffset = getBlockOffset() + getBlock()->getPosition();
 
-	UT_return_val_if_fail( iDocumentPosition >= iRunOffset && iDocumentPosition < iRunOffset + getLength() &&
+	UT_return_val_if_fail( iDocumentPosition >= iRunOffset && iDocumentPosition <= iRunOffset + getLength() &&
 						   m_pRenderInfo,
 						   iDocumentPosition);
 
@@ -3412,8 +3361,11 @@ UT_uint32 fp_TextRun::adjustCaretPosition(UT_uint32 iDocumentPosition, bool bFor
 	m_pRenderInfo->m_pText = &text;
 	m_pRenderInfo->m_iOffset = iDocumentPosition - iRunOffset;
 	m_pRenderInfo->m_iLength = getLength();
-	
-	return iRunOffset + getGraphics()->adjustCaretPosition(*m_pRenderInfo, bForward);
+	UT_uint32 adjustedPos = iRunOffset + getGraphics()->adjustCaretPosition(*m_pRenderInfo, bForward);
+	if((adjustedPos - iRunOffset) > getLength())
+		adjustedPos = iRunOffset + getLength();
+	_refreshDrawBuffer();
+	return adjustedPos;
 }
 
 void fp_TextRun::adjustDeletePosition(UT_uint32 &iDocumentPosition, UT_uint32 &iCount)
