@@ -99,7 +99,7 @@ void pt_PieceTable::setPieceTableState(PTState pts)
 bool pt_PieceTable::deleteStruxNoUpdate(PL_StruxDocHandle sdh)
 {
 	const pf_Frag_Strux * pfs = static_cast<const pf_Frag_Strux *>(sdh);
-	UT_DEBUGMSG(("SEVIOR: deleting strux no update %x \n",sdh));
+	UT_DEBUGMSG(("SEVIOR: deleting strux no update %p \n",sdh));
 	pf_Frag * pf = pfs->getNext();
 	if(pf != NULL && pf->getType() == pf_Frag::PFT_FmtMark)
 	{
@@ -111,6 +111,33 @@ bool pt_PieceTable::deleteStruxNoUpdate(PL_StruxDocHandle sdh)
 	return true;
 }
 
+
+/*!
+ * Use this for deleting unused sections of the document during import.
+ * In Particular use this to remove unused headers/footers.
+ */
+bool pt_PieceTable::deleteFragNoUpdate(pf_Frag * pf)
+{
+	UT_DEBUGMSG(("SEVIOR: deleting frag no update %p \n",pf));
+	getFragments().unlinkFrag(pf);
+	delete pf;
+	return true;
+}
+
+bool pt_PieceTable::createAndSendDocPropCR( const gchar ** pAtts, const gchar ** pProps)
+{
+	PT_AttrPropIndex indexAP = 0;
+	PP_AttrProp * pAP = new PP_AttrProp();
+	pAP->setAttributes(pAtts);
+	pAP->setProperties(pProps);
+	bool b = m_varset.addIfUniqueAP(pAP,&indexAP);
+	PX_ChangeRecord * pcr= new PX_ChangeRecord(PX_ChangeRecord::PXT_ChangeDocProp,0,indexAP,0);
+	const pf_Frag_Strux * pfStart = static_cast<pf_Frag_Strux *>(getFragments().getFirst());
+	m_pDocument->notifyListeners(pfStart, pcr);
+	delete pcr;
+	return b;
+}
+
 bool pt_PieceTable::createAndSendCR(PT_DocPosition iPos, UT_sint32 iType,bool bSave,UT_Byte iGlob)
 {
 	PX_ChangeRecord::PXType cType = static_cast< PX_ChangeRecord::PXType>(iType);
@@ -223,7 +250,7 @@ bool pt_PieceTable::deleteFmtMark(PT_DocPosition dpos)
 bool pt_PieceTable::insertStruxNoUpdateBefore(PL_StruxDocHandle sdh, PTStruxType pts,const gchar ** attributes )
 {
 	const pf_Frag_Strux * pfs = static_cast<const pf_Frag_Strux *>(sdh);
-	UT_DEBUGMSG(("SEVIOR: Inserting strux of type %d no update %x \n",pts,sdh));
+	UT_DEBUGMSG(("SEVIOR: Inserting strux of type %d no update %p \n",pts,sdh));
 //
 // Create an indexAP
 //
@@ -232,6 +259,7 @@ bool pt_PieceTable::insertStruxNoUpdateBefore(PL_StruxDocHandle sdh, PTStruxType
 	{		
 		PT_AttrPropIndex pAPIold = indexAP;
 		bool bMerged = m_varset.mergeAP(PTC_AddFmt,pAPIold,attributes,NULL,&indexAP,getDocument());
+		UT_UNUSED(bMerged);
 		UT_ASSERT_HARMLESS(bMerged);
 	}
 //
@@ -1000,13 +1028,22 @@ bool pt_PieceTable::_getStruxOfTypeFromPosition(PT_DocPosition dpos,
 	*ppfs = NULL;
 
 	pf_Frag_Strux * pfs = NULL;
-	bool wantFootNoteType = (pts == PTX_EndFootnote || pts == PTX_SectionFootnote || pts == PTX_EndEndnote || pts == PTX_SectionEndnote || pts == PTX_SectionTOC || pts == PTX_EndTOC);
+	bool wantFootNoteType = (pts == PTX_EndFootnote || pts == PTX_SectionFootnote || pts == PTX_EndEndnote || pts == PTX_SectionEndnote || pts == PTX_SectionAnnotation || pts == PTX_EndAnnotation || pts == PTX_SectionTOC || pts == PTX_EndTOC);
+
 	if (!_getStruxFromPosition(dpos,&pfs, !wantFootNoteType))
 		return false;
 
 	PTStruxType pfsType = pfs->getStruxType();
 	xxx_UT_DEBUGMSG(("Got strux type %d \n",pfs->getStruxType()));
-	if (pfsType == pts || (pts == PTX_Section && pfsType == PTX_SectionHdrFtr) || (pts == PTX_SectionFootnote && pfsType == PTX_SectionFootnote) || (pts == PTX_SectionEndnote && pfsType == PTX_SectionEndnote) || (pts == PTX_SectionTable && pfsType == PTX_SectionTable) || (pts == PTX_SectionCell && pfsType == PTX_SectionCell) || (pts == PTX_EndTable && pfsType == PTX_EndTable) || (pts == PTX_EndCell && pfsType == PTX_EndCell) || (pts == PTX_SectionTOC && pfsType == PTX_SectionTOC)  )		// is it of the type we want
+	if (pfsType == pts || (pts == PTX_Section && pfsType == PTX_SectionHdrFtr)
+		|| (pts == PTX_SectionFootnote && pfsType == PTX_SectionFootnote) 
+		|| (pts == PTX_SectionAnnotation && pfsType == PTX_SectionAnnotation) 
+		|| (pts == PTX_SectionEndnote && pfsType == PTX_SectionEndnote) 
+		|| (pts == PTX_SectionTable && pfsType == PTX_SectionTable) 
+		|| (pts == PTX_SectionCell && pfsType == PTX_SectionCell) 
+		|| (pts == PTX_EndTable && pfsType == PTX_EndTable) 
+		|| (pts == PTX_EndCell && pfsType == PTX_EndCell) 
+		|| (pts == PTX_SectionTOC && pfsType == PTX_SectionTOC)  )		// is it of the type we want
 	{
 		*ppfs = pfs;
 		return true;
@@ -1065,6 +1102,8 @@ bool pt_PieceTable::_getStruxOfTypeFromPosition(PT_DocPosition dpos,
  * (a) It encounters a strux first.
  * (b) It encounters an end hyperlink first
  * (c) It encounters the begin of document
+ *
+ * FIXME!! Should this code work for annotations too?
  */
 pf_Frag *    pt_PieceTable::_findPrevHyperlink(pf_Frag * pfStart)
 {
