@@ -34,7 +34,6 @@
 #include "xap_Menu_ActionSet.h"
 #include "xap_EncodingManager.h"
 
-#include "ap_Menu_Id.h"
 #include "ap_Menu_Id.h"
 #include "ap_Strings.h"
 
@@ -52,7 +51,7 @@
 		EV_EditMouseContext			m_emc;
 	};
 
-	class _vectt
+	class ABI_EXPORT _vectt
 	{
 	public:
 		_vectt(_tt * orig):
@@ -83,7 +82,7 @@
 			};
 		void insertItemAt(void * p, XAP_Menu_Id id)
 			{
-				UT_uint32 i = 0;
+				UT_sint32 i = 0;
 				bool bFound = false;
 				for(i=0; i< m_Vec_lt.getItemCount() && !bFound; i++)
 				{
@@ -105,7 +104,7 @@
 			};
 		void insertItemBefore(void * p, XAP_Menu_Id id)
 			{
-				UT_uint32 i = 0;
+				UT_sint32 i = 0;
 				bool bFound = false;
 				for(i=0; i< m_Vec_lt.getItemCount() && !bFound; i++)
 				{
@@ -127,7 +126,7 @@
 			};
 		void removeItem(XAP_Menu_Id id)
 			{
-				UT_uint32 i = 0;
+				UT_sint32 i = 0;
 				bool bFound = false;
 				for(i=0; i< m_Vec_lt.getItemCount(); i++)
 				{
@@ -263,7 +262,8 @@ XAP_Menu_Id XAP_Menu_Factory::getNewID(void)
 		m_maxID++;
 		return m_maxID;
 	}
-	UT_uint32 i,j =0;
+	UT_sint32 i =0;
+	UT_uint32 j =0;
 	for(i=0; i < m_vecTT.getItemCount(); i++)
 	{
 		_vectt * pTT = (_vectt *) m_vecTT.getNthItem(i);
@@ -287,7 +287,7 @@ EV_Menu_Layout * XAP_Menu_Factory::CreateMenuLayout(const char * szName)
 {
 	UT_return_val_if_fail (szName && *szName, NULL);		// no defaults
 
-	for (UT_uint32 k=0; k< m_vecTT.getItemCount(); k++)
+	for (UT_sint32 k=0; k< m_vecTT.getItemCount(); k++)
 	{
 		_vectt * pVectt = (_vectt *)m_vecTT.getNthItem(k);
 		if (pVectt == NULL)
@@ -315,7 +315,7 @@ EV_Menu_Layout * XAP_Menu_Factory::CreateMenuLayout(const char * szName)
 const char * XAP_Menu_Factory::FindContextMenu(EV_EditMouseContext emc)
 {
 
-	for (UT_uint32 k=0; k< m_vecTT.getItemCount(); k++)
+	for (UT_sint32 k=0; k< m_vecTT.getItemCount(); k++)
 	{
 		_vectt * pVectt = (_vectt *) m_vecTT.getNthItem(k);
 		if (pVectt == NULL)
@@ -331,12 +331,12 @@ const char * XAP_Menu_Factory::FindContextMenu(EV_EditMouseContext emc)
 }
 
 XAP_Menu_Id XAP_Menu_Factory::addNewMenuAfter(const char * szMenu, 
-											   const char * szLanguage,
+											   const char * /*szLanguage*/,
 											   const XAP_Menu_Id afterID, 
 											   EV_Menu_LayoutFlags flags, XAP_Menu_Id newID)
 {
 	UT_return_val_if_fail (szMenu && *szMenu, 0);		// no defaults
-	UT_uint32 k = 0;
+	UT_sint32 k = 0;
 	bool bFoundMenu = false;
 	_vectt * pVectt = NULL;
 	for (k=0; (k< m_vecTT.getItemCount()) && !bFoundMenu; k++)
@@ -370,13 +370,13 @@ XAP_Menu_Id XAP_Menu_Factory::addNewMenuAfter(const char * szMenu,
 }
 
 XAP_Menu_Id XAP_Menu_Factory::addNewMenuAfter(const char * szMenu, 
-											  const char * szLanguage,
+											  const char * /*szLanguage*/,
 											  const char * szAfter, 
 											  EV_Menu_LayoutFlags flags,
 											  XAP_Menu_Id newID)
 {
 	UT_return_val_if_fail (szMenu && *szMenu, 0);		// no defaults
-	UT_uint32 k = 0;
+	UT_sint32 k = 0;
 	bool bFoundMenu = false;
 	_vectt * pVectt = NULL;
 	for (k=0; (k< m_vecTT.getItemCount()) && !bFoundMenu; k++)
@@ -429,12 +429,12 @@ XAP_Menu_Id XAP_Menu_Factory::addNewMenuAfter(const char * szMenu,
 }
 
 XAP_Menu_Id XAP_Menu_Factory::addNewMenuBefore(const char * szMenu, 
-											   const char * szLanguage,
+											   const char * /*szLanguage*/,
 											   const XAP_Menu_Id beforeID, 
 											   EV_Menu_LayoutFlags flags, XAP_Menu_Id newID)
 {
 	UT_return_val_if_fail (szMenu && *szMenu, 0);		// no defaults
-	UT_uint32 k = 0;
+	UT_sint32 k = 0;
 	bool bFoundMenu = false;
 	_vectt * pVectt = NULL;
 	for (k=0; (k< m_vecTT.getItemCount()) && !bFoundMenu; k++)
@@ -475,12 +475,12 @@ XAP_Menu_Id XAP_Menu_Factory::addNewMenuBefore(const char * szMenu,
 }
 
 XAP_Menu_Id XAP_Menu_Factory::addNewMenuBefore(const char * szMenu, 
-											   const char * szLanguage,
+											   const char * /*szLanguage*/,
 											   const char * szBefore, 
 											   EV_Menu_LayoutFlags flags, XAP_Menu_Id newID)
 {
 	UT_return_val_if_fail (szMenu && *szMenu, 0);		// no defaults
-	UT_uint32 k = 0;
+	UT_sint32 k = 0;
 	bool bFoundMenu = false;
 	_vectt * pVectt = NULL;
 	for (k=0; (k< m_vecTT.getItemCount()) && !bFoundMenu; k++)
@@ -550,11 +550,11 @@ XAP_Menu_Id XAP_Menu_Factory::addNewMenuBefore(const char * szMenu,
  * Language set szLanguage
  */
 XAP_Menu_Id XAP_Menu_Factory::removeMenuItem(const char * szMenu, 
-							  const char * szLanguage,  
+							  const char * /*szLanguage*/,  
 							  XAP_Menu_Id nukeID)
 {
 	UT_return_val_if_fail (szMenu && *szMenu, 0);		// no defaults
-	UT_uint32 k = 0;
+	UT_sint32 k = 0;
 	bool bFoundMenu = false;
 	_vectt * pVectt = NULL;
 	for (k=0; (k< m_vecTT.getItemCount()) && !bFoundMenu; k++)
@@ -578,11 +578,11 @@ XAP_Menu_Id XAP_Menu_Factory::removeMenuItem(const char * szMenu,
  * Language set szLanguage
  */
 XAP_Menu_Id XAP_Menu_Factory::removeMenuItem(const char * szMenu,
-									  const char * szLanguage,
+									  const char * /*szLanguage*/,
 											 const char * szNuke)
 {
 	UT_return_val_if_fail (szMenu && *szMenu, 0);		// no defaults
-	UT_uint32 k = 0;
+	UT_sint32 k = 0;
 	bool bFoundMenu = false;
 	_vectt * pVectt = NULL;
 	for (k=0; (k< m_vecTT.getItemCount()) && !bFoundMenu; k++)
@@ -737,7 +737,7 @@ UT_uint32 XAP_Menu_Factory::GetMenuLabelSetLanguageCount(void)
 	return 1;
 }
 
-const char * XAP_Menu_Factory::GetNthMenuLabelLanguageName(UT_uint32 ndx)
+const char * XAP_Menu_Factory::GetNthMenuLabelLanguageName(UT_uint32 /*ndx*/)
 {
 	return m_pLabelSet->getLanguage();
 }
@@ -746,7 +746,7 @@ const char * XAP_Menu_Factory::GetNthMenuLabelLanguageName(UT_uint32 ndx)
  * afterID has just been created. All labels of value equal or greater 
  * must be incremented
  */
-bool XAP_Menu_Factory::addNewLabel(const char * szLanguage, 
+bool XAP_Menu_Factory::addNewLabel(const char * /*szLanguage*/, 
 										XAP_Menu_Id newID, 
 										const char * szNewName,
 										const char * szNewTooltip)
@@ -756,8 +756,8 @@ bool XAP_Menu_Factory::addNewLabel(const char * szLanguage,
 	return m_pLabelSet->addLabel(newLab);
 }
 
-bool XAP_Menu_Factory::removeLabel(const char * szLanguage, 
-									   XAP_Menu_Id nukeID)
+bool XAP_Menu_Factory::removeLabel(const char * /*szLanguage*/, 
+									   XAP_Menu_Id /*nukeID*/)
 {
 	return false;
 }
@@ -807,6 +807,5 @@ void XAP_Menu_Factory::removeContextMenu(EV_EditMouseContext menuID)
 {
 	_vectt * pVectt;
 	m_vecTT.setNthItem (menuID, NULL, (const void**)&pVectt);
-	if (pVectt)
-		delete pVectt;
+	DELETEP(pVectt);
 }
