@@ -162,26 +162,33 @@ BeginLayout(Main,0)
 	
 	BeginSubMenu(AP_MENU_ID_INSERT)
 		MenuItem(AP_MENU_ID_INSERT_BREAK)
-		MenuItem(AP_MENU_ID_INSERT_PAGENO)
-		MenuItem(AP_MENU_ID_INSERT_DATETIME)
-		MenuItem(AP_MENU_ID_INSERT_FIELD)
-		MenuItem(AP_MENU_ID_INSERT_TEXTBOX)
-#if !XAP_SIMPLE_MENU
-		MenuItem(AP_MENU_ID_INSERT_MAILMERGE)
-#endif
-		MenuItem(AP_MENU_ID_INSERT_SYMBOL)
-		
-		Separator()
-
 		MenuItem(AP_MENU_ID_INSERT_HEADER)
 		MenuItem(AP_MENU_ID_INSERT_FOOTER)
-		MenuItem(AP_MENU_ID_INSERT_FILE)
-		MenuItem(AP_MENU_ID_INSERT_BOOKMARK)
-		MenuItem(AP_MENU_ID_INSERT_HYPERLINK)
+
+		Separator()
+
+        MenuItem(AP_MENU_ID_TABLE_INSERT_TABLE)
+		MenuItem(AP_MENU_ID_INSERT_TEXTBOX)
 		MenuItem(AP_MENU_ID_INSERT_TABLEOFCONTENTS)	
         MenuItem(AP_MENU_ID_INSERT_FOOTNOTE)
 		MenuItem(AP_MENU_ID_INSERT_ENDNOTE)
 
+		Separator()
+
+		MenuItem(AP_MENU_ID_INSERT_SYMBOL)
+		MenuItem(AP_MENU_ID_INSERT_PAGENO)
+		MenuItem(AP_MENU_ID_INSERT_DATETIME)
+		MenuItem(AP_MENU_ID_INSERT_FIELD)
+		MenuItem(AP_MENU_ID_INSERT_BOOKMARK)
+		MenuItem(AP_MENU_ID_INSERT_HYPERLINK)
+#if !XAP_SIMPLE_MENU
+		MenuItem(AP_MENU_ID_INSERT_MAILMERGE)
+#endif
+		
+		Separator()
+
+		MenuItem(AP_MENU_ID_INSERT_FILE)
+
 #if defined(TOOLKIT_GTK) && !XAP_SIMPLE_MENU
 		MenuItem(AP_MENU_ID_INSERT_CLIPART)
 #endif
@@ -202,6 +209,7 @@ BeginLayout(Main,0)
 		MenuItem(AP_MENU_ID_FMT_FONT)
 		MenuItem(AP_MENU_ID_FMT_PARAGRAPH)
 		MenuItem(AP_MENU_ID_FMT_BULLETS)
+		MenuItem(AP_MENU_ID_TABLE_FORMAT)
 		MenuItem(AP_MENU_ID_FMT_FRAME)
 		MenuItem(AP_MENU_ID_FMT_IMAGE)
 #if 0 // someone code and turn this back on
@@ -327,7 +335,6 @@ BeginLayout(Main,0)
 	BeginSubMenu(AP_MENU_ID_TABLE)
 
 		BeginSubMenu(AP_MENU_ID_TABLE_INSERT)
-			MenuItem(AP_MENU_ID_TABLE_INSERT_TABLE)
 			MenuItem(AP_MENU_ID_TABLE_INSERT_COLUMNS_BEFORE)
 			MenuItem(AP_MENU_ID_TABLE_INSERT_COLUMNS_AFTER)
 			MenuItem(AP_MENU_ID_TABLE_INSERT_ROWS_BEFORE)
@@ -364,7 +371,6 @@ BeginLayout(Main,0)
 // Not for 2.4
 		MenuItem(AP_MENU_ID_TABLE_SPLIT_TABLE)
 #endif
-		MenuItem(AP_MENU_ID_TABLE_FORMAT)
 		BeginSubMenu(AP_MENU_ID_TABLE_TEXTTOTABLE)
 			MenuItem(AP_MENU_ID_TABLE_TEXTTOTABLE_ALL)
 			MenuItem(AP_MENU_ID_TABLE_TEXTTOTABLE_NOSPACES)
@@ -410,7 +416,7 @@ BeginLayout(Main,0)
 	EndSubMenu()
 	BeginSubMenu(AP_MENU_ID_HELP)
 		MenuItem(AP_MENU_ID_HELP_CONTENTS)
-		MenuItem(AP_MENU_ID_HELP_INDEX)
+		MenuItem(AP_MENU_ID_HELP_INTRO)
 		MenuItem(AP_MENU_ID_HELP_SEARCH)
 		MenuItem(AP_MENU_ID_HELP_CHECKVER)
 		MenuItem(AP_MENU_ID_HELP_REPORT_BUG)
