@@ -36,10 +36,11 @@ AP_Preview_Annotation::AP_Preview_Annotation(XAP_DialogFactory * pDlgFactory,XAP
 	m_height(PREVIEW_DEFAULT_HEIGHT),
 	m_left(0),
 	m_top(0),
+	m_Offset(0),
 	m_clrBackground(255, 247, 177),
-	m_pTitle("n/a"),
-	m_pAuthor("n/a"),
-	m_pDescription("n/a")
+	m_sTitle("n/a"),
+	m_sAuthor("n/a"),
+	m_sDescription("n/a")
 {
 }
 
@@ -51,24 +52,26 @@ AP_Preview_Annotation::~AP_Preview_Annotation()
 void AP_Preview_Annotation::setTitle(const gchar * pTitle)
 {
 	UT_return_if_fail(pTitle);
-	m_pTitle = pTitle;
+	m_sTitle = pTitle;
 }
+
 void AP_Preview_Annotation::setAuthor(const gchar * pAuthor)
 {
 	UT_return_if_fail(pAuthor);
-	m_pAuthor = pAuthor;
+	m_sAuthor = pAuthor;
 }
+
 void AP_Preview_Annotation::setDescription(const gchar * pDescription)
 {
 	UT_return_if_fail(pDescription);
-	m_pDescription = pDescription;
+	m_sDescription = pDescription;
 }
+
 void AP_Preview_Annotation::setAnnotationID(UT_uint32 aID)
 {
 	m_iAID = aID;
 }
 
-
 void AP_Preview_Annotation::_createAnnotationPreviewFromGC(GR_Graphics * gc, UT_uint32 width, UT_uint32 height)
 {
 	UT_ASSERT(gc);
@@ -85,45 +88,22 @@ void AP_Preview_Annotation::_createAnnotationPreviewFromGC(GR_Graphics * gc, UT_
  */
 void AP_Preview_Annotation::setSizeFromAnnotation(void)
 {
-	//
-	// Get the font and features
-	//
-	
-	// "font-family"
-	const char * pszFamily = "Times New Roman";
-	
-	// "font-style"
-	const char * pszStyle = "normal";
-	
-	// "font-variant"
-	const char * pszVariant = "normal";
-	
-	// "font-stretch"
-	const char * pszStretch = "normal";
-	
-	// "font-size"
-	const char * pszSize="12pt";
-	
-	// "font-weight"
-	const char * pszWeight = "normal";
-
 	FV_View * pView = static_cast<FV_View *>(getActiveFrame()->getCurrentView());
 	GR_Graphics * pG = NULL;
 	UT_return_if_fail(pView);
 	pG = pView->getGraphics();
 
 	UT_return_if_fail(pG);
-	GR_Font * pFont = pG->findFont(pszFamily, pszStyle,
-				       pszVariant, pszWeight,
-				       pszStretch, pszSize,
+	GR_Font * pFont = pG->findFont("Times New Roman", "normal",
+				       "normal", "normal",
+				       "normal", "12pt",
 				       NULL);
-	
 	UT_return_if_fail(pFont);
 	
 	double rat = 100./static_cast<double>(pG->getZoomPercentage());
 	UT_sint32 iHeight = pG->getFontAscent(pFont) + pG->tlu(7);
 	iHeight = static_cast<UT_sint32>(static_cast<double>(iHeight));
-	m_drawString = m_pDescription;
+	m_drawString = m_sDescription;
 	UT_sint32 len = m_drawString.size();
 	pG->setFont(pFont);
 	UT_sint32 iwidth = pG->measureString(m_drawString.ucs4_str(),0,len,NULL) + pG->tlu(6);
@@ -131,55 +111,21 @@ void AP_Preview_Annotation::setSizeFromAnnotation(void)
 	m_width = static_cast<UT_sint32>(static_cast<double>(pG->tdu(iwidth))*rat);
 	m_height = static_cast<UT_sint32>(static_cast<double>(pG->tdu(iHeight))*rat);
 	if(pG->tdu(pView->getWindowWidth()) < m_width)
-	  m_width = pG->tdu(pView->getWindowWidth());
+		m_width = pG->tdu(pView->getWindowWidth());
 	UT_DEBUGMSG(("SetSize from Annotation width %d rat %f \n",m_width,rat));
 }
-// Finally draw the characters in the preview.
+
 void AP_Preview_Annotation::draw(void)
 {
-        m_drawString = m_pDescription;
-	//
-	// Text decorations.
-	//
-	bool isUnder,isOver,isStrike;
+	m_drawString = m_sDescription;
 	
-	isUnder = false;	// "underline"
-	isOver = false;		// "overline"
-	isStrike = false;	// "line-through"
-	
-	//
-	// Foreground and background colors.
-	//
 	UT_RGBColor FGcolor(0,0,0);
 	UT_RGBColor BGcolor(m_clrBackground);
 	
-	//
-	// Get the font and features
-	//
-	
-	// "font-family"
-	const char * pszFamily = "Times New Roman";
-	
-	// "font-style"
-	const char * pszStyle = "normal";
-	
-	// "font-variant"
-	const char * pszVariant = "normal";
-	
-	// "font-stretch"
-	const char * pszStretch = "normal";
-	
-	// "font-size"
-	const char * pszSize="12pt";
-	
-	// "font-weight"
-	const char * pszWeight = "normal";
-	
-	m_pFont = m_gc->findFont(pszFamily, pszStyle,
-							 pszVariant, pszWeight,
-							 pszStretch, pszSize,
+	m_pFont = m_gc->findFont("Times New Roman", "normal",
+							 "normal", "normal",
+							 "normal", "12pt",
 							 NULL);
-	
 	UT_ASSERT_HARMLESS(m_pFont);
 	if(!m_pFont)
 	{
@@ -193,10 +139,8 @@ void AP_Preview_Annotation::draw(void)
 	m_iDescent = m_gc->getFontDescent(m_pFont);
 	m_iHeight = m_gc->getFontHeight(m_pFont);
 	
-	//
-	// Clear the screen!
-	//
 	clearScreen();
+
 	//
 	// Calculate the draw coordinates position
 	//
@@ -215,24 +159,6 @@ void AP_Preview_Annotation::draw(void)
 	//
 	m_gc->setColor(FGcolor);
 	painter.drawChars(m_drawString.ucs4_str(), 0, len, iLeft, iTop);
-	//
-	// Do the decorations
-	//
-	if(isUnder)
-	{
-		UT_sint32 iDrop = iTop + m_iAscent + m_iDescent/3;
-		painter.drawLine(iLeft,iDrop,iLeft+twidth,iDrop);
-	}
-	if(isOver)
-	{
-		UT_sint32 iDrop = iTop + m_gc->tlu(1) + (UT_MAX(m_gc->tlu(10),m_iAscent) - m_gc->tlu(10))/8;
-		painter.drawLine(iLeft,iDrop,iLeft+twidth,iDrop);
-	}
-	if(isStrike)
-	{
-		UT_sint32 iDrop = iTop + m_iAscent * 2 /3;
-		painter.drawLine(iLeft,iDrop,iLeft+twidth,iDrop);
-	}
 	
 	// bad hardcoded color, but this will probably [ <-this assumption is the bad thing :) ] never be different anyway
 	m_gc->setColor(UT_RGBColor(0,0,0));
@@ -242,21 +168,8 @@ void AP_Preview_Annotation::draw(void)
 	painter.drawLine(m_gc->tlu(getWindowWidth()) - m_gc->tlu(1), m_gc->tlu(getWindowHeight()) - m_gc->tlu(1), 0,
 					 m_gc->tlu(getWindowHeight()) - m_gc->tlu(1));
 	painter.drawLine(0, m_gc->tlu(getWindowHeight()) - m_gc->tlu(1), 0, 0);
-	
-	// somehow this gets ignored...
-	//activate();
 }
 
-/*void AP_Preview_Annotation::activate(void)
-{
-	UT_DEBUGMSG(("AP_Preview_Annotation: no activate implementation\n"));
-}*/
-
-/*void AP_Preview_Annotation::_bringToTop(void)
-{
-	UT_DEBUGMSG(("AP_Preview_Annotation: no _bringToTop\n"));
-}*/
-
 void AP_Preview_Annotation::clearScreen(void)
 {
 	UT_sint32 iWidth = m_gc->tlu(getWindowWidth());
@@ -271,7 +184,6 @@ void AP_Preview_Annotation::clearScreen(void)
 void AP_Preview_Annotation::setActiveFrame(XAP_Frame *pFrame)
 {
 	UT_DEBUGMSG(("AP_Preview_Annotation: setActiveFrame\n"));
-	//notifyActiveFrame(getActiveFrame());
 	notifyActiveFrame(pFrame);
 }
 
@@ -281,11 +193,23 @@ void AP_Preview_Annotation::setActiveFrame(XAP_Frame *pFrame)
  */
 void  AP_Preview_Annotation::setXY(UT_sint32 x, UT_sint32 y)
 {
-  m_left = x - m_width/2;
-  m_top = y;
-  if(m_top < 0)
-    m_top = 0;
-  if(m_left < 0)
-    m_left = 0;
-  UT_DEBUGMSG(("AP_Preview_Annotation: setXY top %d, left %d\n",m_top,m_left));
+	m_left = x - m_width/2;
+		m_top = y;
+	if(m_top < 0)
+		m_top = 0;
+	if(m_left < 0)
+		m_left = 0;
+	UT_DEBUGMSG(("AP_Preview_Annotation: setXY top %d, left %d\n", m_top, m_left));
+}
+
+/*!
+ * In Gtk Apps it is really hard to translate the position of the 
+ * popup window to the actual position of the run. In insead use the
+ * location of the mouse when it crosses the run.
+ * If induces a vertical uncertainty in here the popup appears.
+ * Setting this offset corrects for this.
+ */
+void AP_Preview_Annotation::setOffset(UT_sint32 offset)
+{
+	m_Offset = offset;
 }
